@@ -33,8 +33,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <telepathy-glib/account-manager.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <libempathy/empathy-presence-manager.h>
 #include <libempathy/empathy-utils.h>
@@ -759,7 +758,7 @@ update_sensitivity_am_prepared_cb (GObject *source_object,
 		return;
 	}
 
-	accounts = tp_account_manager_get_valid_accounts (manager);
+	accounts = tp_account_manager_dup_valid_accounts (manager);
 
 	for (l = accounts ; l != NULL ; l = g_list_next (l)) {
 		TpAccount *a = TP_ACCOUNT (l->data);
@@ -770,7 +769,7 @@ update_sensitivity_am_prepared_cb (GObject *source_object,
 		}
 	}
 
-	g_list_free (accounts);
+	g_list_free_full (accounts, g_object_unref);
 
 	if (!g_network_monitor_get_network_available (priv->connectivity))
 		sensitive = FALSE;
