@@ -393,7 +393,7 @@ individual_added (EmpathyRosterView *self,
     {
       GList *groups, *l;
 
-      groups = empathy_roster_model_get_groups_for_individual (self->priv->model,
+      groups = empathy_roster_model_dup_groups_for_individual (self->priv->model,
           individual);
 
       if (g_list_length (groups) > 0)
@@ -409,7 +409,7 @@ individual_added (EmpathyRosterView *self,
           add_to_group (self, individual, EMPATHY_ROSTER_MODEL_GROUP_UNGROUPED);
         }
 
-      g_list_free (groups);
+      g_list_free_full (groups, g_free);
     }
 
   tp_g_signal_connect_object (individual, "notify::is-favourite",
@@ -588,14 +588,14 @@ contact_in_top (EmpathyRosterView *self,
 
       individual = empathy_roster_contact_get_individual (contact);
 
-      groups = empathy_roster_model_get_groups_for_individual (
+      groups = empathy_roster_model_dup_groups_for_individual (
           self->priv->model, individual);
 
       if (g_list_find_custom (groups, EMPATHY_ROSTER_MODEL_GROUP_TOP_GROUP,
             (GCompareFunc) g_strcmp0) != NULL)
         result = TRUE;
 
-      g_list_free (groups);
+      g_list_free_full (groups, g_free);
 
       return result;
     }
@@ -907,6 +907,7 @@ filter_group (EmpathyRosterView *self,
     EmpathyRosterGroup *group)
 {
   GList *widgets, *l;
+  gboolean result = FALSE;
 
   /* Display the group if it contains at least one displayed contact */
   widgets = empathy_roster_group_get_widgets (group);
@@ -915,10 +916,15 @@ filter_group (EmpathyRosterView *self,
       EmpathyRosterContact *contact = l->data;
 
       if (contact_should_be_displayed (self, contact))
-        return TRUE;
+        {
+          result = TRUE;
+          break;
+        }
     }
 
-  return FALSE;
+  g_list_free (widgets);
+
+  return result;
 }
 
 static gboolean
@@ -1045,6 +1051,17 @@ empathy_roster_view_constructed (GObject *object)
   egg_list_box_set_activate_on_single_click (EGG_LIST_BOX (self), FALSE);
 }
 
+static void
+clear_view (EmpathyRosterView *self)
+{
+  g_hash_table_remove_all (self->priv->roster_contacts);
+  g_hash_table_remove_all (self->priv->roster_groups);
+  g_hash_table_remove_all (self->priv->displayed_contacts);
+
+  gtk_container_foreach (GTK_CONTAINER (self),
+      (GtkCallback) gtk_widget_destroy, NULL);
+}
+
 static void
 empathy_roster_view_dispose (GObject *object)
 {
@@ -1052,6 +1069,10 @@ empathy_roster_view_dispose (GObject *object)
   void (*chain_up) (GObject *) =
       ((GObjectClass *) empathy_roster_view_parent_class)->dispose;
 
+  /* Start by clearing the view so our internal hash tables are cleared from
+   * objects being destroyed. */
+  clear_view (self);
+
   stop_flashing (self);
 
   empathy_roster_view_set_live_search (self, NULL);
@@ -1377,17 +1398,6 @@ empathy_roster_view_show_offline (EmpathyRosterView *self,
   g_object_notify (G_OBJECT (self), "show-offline");
 }
 
-static void
-clear_view (EmpathyRosterView *self)
-{
-  g_hash_table_remove_all (self->priv->roster_contacts);
-  g_hash_table_remove_all (self->priv->roster_groups);
-  g_hash_table_remove_all (self->priv->displayed_contacts);
-
-  gtk_container_foreach (GTK_CONTAINER (self),
-      (GtkCallback) gtk_widget_destroy, NULL);
-}
-
 void
 empathy_roster_view_show_groups (EmpathyRosterView *self,
     gboolean show)
